<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package quarty
 */

?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<!-- Meta Data -->
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta http-equiv="X-UA-Compatible" content="IE=edge">
	<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
	<link rel="profile" href="https://gmpg.org/xfn/11">

	<?php wp_head(); ?>
</head>

<?php

$header_layout = get_field( 'header_layout', 'option' );
$header_logo = get_field( 'header_logo', 'option' );
$social_links = get_field( 'social_links', 'option' );

$page_layout = 0;
if ( is_singular( 'post' ) ) {
  $page_layout = get_field( 'post_layout', 'option' );
} else if ( is_singular( 'portfolio' ) ) {
  $page_layout = get_field( 'portfolio_layout', 'option' );
} else {
  $page_layout = get_field( 'page_layout' );
}

if ( is_archive() || is_search() ) {
  $page_layout = 0;
}

?>

<body <?php body_class(); ?>>
	<?php wp_body_open(); ?>

  <div class="qrt-app">
    <?php $preloader_hide_logo = get_field( 'preloader_hide_logo', 'option' ) ?>
    <div class="qrt-preloader">
      <div class="qrt-preloader-content">
        <div class="qrt-logo">
          <?php if ( ! $preloader_hide_logo && $header_logo ) : ?><img src="<?php echo esc_url( $header_logo ); ?>" alt="<?php echo esc_attr( bloginfo('name') ); ?>"><?php endif; ?>
        </div>
        <div id="preloader" class="qrt-preloader-load"></div>
      </div>
    </div>

    <div id="cursor" class="qrt-cursor">
      <div></div>
      <div class="qrt-follower"><i class="fas fa-circle-notch"></i></div>
    </div>

    <?php 
    if ( ! $header_layout ) :
      get_template_part( 'template-elements/header', 'default' );
    elseif( !\Elementor\Plugin::$instance->preview->is_preview_mode() ) :
      get_template_part( 'template-elements/header', 'builder' );
    endif; ?>

    <div class="qrt-left-bar">
      <div class="qrt-current-page-title"></div>
      <?php if ( $social_links ) : ?>
      <div class="qrt-social-links">
        <?php foreach ( $social_links as $social ) : ?>
        <a href="<?php echo esc_url( $social['url'] ); ?>" target="_blank" class="qrt-social-link qrt-cursor-color qrt-cursor-scale">
          <?php echo wp_kses_post( $social['icon'] ); ?>
        </a>
        <?php endforeach; ?>
      </div>
      <?php endif; ?>
    </div>
    <div class="qrt-curtain"></div>

    <div id="qrt-dynamic-content" class="qrt-dynamic-content">
      <div class="qrt-content" id="qrt-scroll-content">
        <div class="<?php if ( $page_layout == 1 ) : ?>qrt-half-content-frame<?php else :?>qrt-content-frame<?php endif; ?>">
          <div class="qrt-left">
